@@ -1,5 +1,6 @@
 import click
 from stochasticx.auth.auth import Stochastic
+from getpass import getpass
 
 stochastic = Stochastic()
 
@@ -7,12 +8,15 @@ stochastic = Stochastic()
 @click.option('--username', help='Username for login')
 @click.option('--password', help='Password for login')
 def login(username, password):
-    if username is None or password is None:
-        stochastic.login()
-    else:
-        stochastic.login(username, password)
+    if username is None:
+        username = input("Enter your email: ")
+    
+    if password is None:
+        password = getpass()
         
-    click.echo("Login successfully")
+    stochastic.login(username, password)
+        
+    click.secho("[+] Login successfully", fg="green", bold=True)
 
 
 @click.group(name="me")
@@ -22,20 +26,23 @@ def me():
 
 @click.command(name="profile")
 def profile():
+    click.secho("\n[+] Collecting profile information", fg='blue', bold=True)
     profile_info = stochastic.get_profile()
-    click.echo(profile_info)
+    click.secho(profile_info, bold=True)
     
 
 @click.command(name="company")
 def company():
     company_info = stochastic.get_company()
-    click.echo(company_info)
+    click.secho("\n[+] Collecting company information", fg='blue', bold=True)
+    click.secho(company_info, bold=True)
     
 
 @click.command(name="usage")
 def usage():
     usage_info = stochastic.get_usage_quota()
-    click.echo(usage_info)
+    click.secho("\n[+] Collecting usage information", fg='blue', bold=True)
+    click.secho(usage_info, bold=True)
     
 
 me.add_command(profile)
