@@ -5,6 +5,7 @@ from stochasticx.client.jobs import jobs
 from stochasticx.client.auth import login, me
 from stochasticx.client.deployments import instances, deployments
 from stochasticx.client.inferences import inference
+from stochasticx.client.local import stable_diffusion
 
 
 @click.group()
@@ -19,4 +20,5 @@ cli.add_command(login)
 cli.add_command(me)
 cli.add_command(instances)
 cli.add_command(deployments)
-cli.add_command(inference)
\ No newline at end of file
+cli.add_command(inference)
+cli.add_command(stable_diffusion)
\ No newline at end of file
